@@ -1,10 +1,10 @@
 """
-Implement clean_country function
+Clean and validate a DataFrame column containing country names.
 """
-import os
 from functools import lru_cache
 from operator import itemgetter
-from typing import Any, Union
+from os import path
+from typing import Any, Union, Tuple, Optional
 
 import dask
 import dask.dataframe as dd
@@ -12,77 +12,110 @@ import numpy as np
 import pandas as pd
 import regex as re
 
-from ..eda.progress_bar import ProgressBar
+from ..progress_bar import ProgressBar
 from .utils import NULL_VALUES, create_report_new, to_dask
 
-COUNTRY_DATA_FILE = os.path.join(os.path.split(os.path.abspath(__file__))[0], "country_data.tsv")
+COUNTRY_DATA_FILE = path.join(path.split(path.abspath(__file__))[0], "country_data.tsv")
 
 DATA = pd.read_csv(COUNTRY_DATA_FILE, sep="\t", encoding="utf-8", dtype=str)
 
 REGEXES = [re.compile(entry, re.IGNORECASE) for entry in DATA.regex]
-# alternative regex search strategy given on line 243
-# REGEXES = re.compile("|".join(f"(?P<a{i}>{x})" for i, x in enumerate(DATA.regex)), re.IGNORECASE)
 
 
 def clean_country(
     df: Union[pd.DataFrame, dd.DataFrame],
     column: str,
-    input_format: str = "auto",
+    input_format: Union[str, Tuple[str, ...]] = "auto",
     output_format: str = "name",
     fuzzy_dist: int = 0,
     strict: bool = False,
     inplace: bool = False,
-    report: bool = True,
     errors: str = "coerce",
+    report: bool = True,
     progress: bool = True,
 ) -> pd.DataFrame:
     """
-    This function cleans countries
+    Clean and standardize country names.
+
+    Read more in the :ref:`User Guide <country_userguide>`.
 
     Parameters
     ----------
     df
-        pandas or Dask DataFrame
+        A pandas or Dask DataFrame containing the data to be cleaned.
     column
-        column name containing messy country data
+        The name of the column containing country names.
     input_format
-        the ISO 3166 input format of the country:
-        "auto" (infers the input format), country name ("name"),
-        official state name ("official"), alpha-2 code ("alpha-2"),
-        alpha-3 code ("alpha-3"), numeric code ("numeric")
+        The ISO 3166 input format of the country.
+            - 'auto': infer the input format
+            - 'name': country name ('United States')
+            - 'official': official state name ('United States of America')
+            - 'alpha-2': alpha-2 code ('US')
+            - 'alpha-3': alpha-3 code ('USA')
+            - 'numeric': numeric code (840)
+
+        Can also be a tuple containing any combination of input formats,
+        for example to clean a column containing alpha-2 and numeric
+        codes set input_format to ('alpha-2', 'numeric').
+
+        (default: 'auto')
     output_format
-        the desired format of the country:
-        country name ("name"), official state name ("official"), alpha-2 code ("alpha-2"),
-        alpha-3 code ("alpha-3"), numeric code ("numeric")
+        The desired ISO 3166 format of the country:
+            - 'name': country name ('United States')
+            - 'official': official state name ('United States of America')
+            - 'alpha-2': alpha-2 code ('US')
+            - 'alpha-3': alpha-3 code ('USA')
+            - 'numeric': numeric code (840)
+
+        (default: 'name')
     fuzzy_dist
         The maximum edit distance (number of single character insertions, deletions
         or substitutions required to change one word into the other) between a country value
-        and input that will count as a match. Only applies to "auto", "name" and "official" formats.
+        and input that will count as a match. Only applies to 'auto', 'name' and 'official'
+        input formats.
+
+        (default: 0)
     strict
-        If True, matching for input formats "name" and "official" are done by looking
-        for a direct match, if False, matching is done by searching the input for a
-        regex match
+        If True, matching for input formats 'name' and 'official' are done by looking
+        for a direct match. If False, matching is done by searching the input for a
+        regex match.
+
+        (default: False)
     inplace
-        If True, delete the given column with dirty data, else, create a new
-        column with cleaned data.
+        If True, delete the column containing the data that was cleaned. Otherwise,
+        keep the original column.
+
+        (default: False)
+    errors
+        How to handle parsing errors.
+            - ‘coerce’: invalid parsing will be set to NaN.
+            - ‘ignore’: invalid parsing will return the input.
+            - ‘raise’: invalid parsing will raise an exception.
+
+        (default: 'coerce')
     report
         If True, output the summary report. Otherwise, no report is outputted.
-    errors {‘ignore’, ‘raise’, ‘coerce’}, default 'coerce'
-        * If ‘raise’, then invalid parsing will raise an exception.
-        * If ‘coerce’, then invalid parsing will be set as NaN.
-        * If ‘ignore’, then invalid parsing will return the input.
+
+        (default: True)
     progress
-        If True, enable the progress bar
+        If True, display a progress bar.
+
+        (default: True)
+
+    Examples
+    --------
+
+    >>> df = pd.DataFrame({'country': [' Canada ', 'US']})
+    >>> clean_country(df, 'country')
+    Country Cleaning Report:
+        2 values cleaned (100.0%)
+    Result contains 2 (100.0%) values in the correct format and 0 null values (0.0%)
+        country  country_clean
+    0   Canada          Canada
+    1        US  United States
     """
     # pylint: disable=too-many-arguments
-
-    input_formats = {"auto", "name", "official", "alpha-2", "alpha-3", "numeric"}
     output_formats = {"name", "official", "alpha-2", "alpha-3", "numeric"}
-    if input_format not in input_formats:
-        raise ValueError(
-            f'input_format {input_format} is invalid, it needs to be one of "auto", '
-            '"name", "official", "alpha-2", "alpha-3" or "numeric'
-        )
     if output_format not in output_formats:
         raise ValueError(
             f'output_format {output_format} is invalid, it needs to be "name", '
@@ -93,6 +126,7 @@ def clean_country(
             "can't do fuzzy matching while strict mode is enabled, "
             "set strict=False for fuzzy matching or fuzzy_dist=0 for strict matching"
         )
+    input_formats = _input_format_to_tuple(input_format)
 
     # convert to dask
     df = to_dask(df)
@@ -103,7 +137,8 @@ def clean_country(
     # amount of different codes to produce the report
     df["clean_code_tup"] = df[column].map_partitions(
         lambda srs: [
-            _format_country(x, input_format, output_format, fuzzy_dist, strict, errors) for x in srs
+            _format_country(x, input_formats, output_format, fuzzy_dist, strict, errors)
+            for x in srs
         ],
         meta=object,
     )
@@ -131,37 +166,63 @@ def clean_country(
 
 
 def validate_country(
-    x: Union[str, int, pd.Series], input_format: str = "auto", strict: bool = True
+    x: Union[str, int, pd.Series],
+    input_format: Union[str, Tuple[str, ...]] = "auto",
+    strict: bool = True,
 ) -> Union[bool, pd.Series]:
     """
-    This function validates countries
+    Validate country names.
+
+    Read more in the :ref:`User Guide <country_userguide>`.
 
     Parameters
     ----------
     x
-        pandas Series of countries or str/int country value
+        pandas Series of countries or str/int country value.
     input_format
-        the ISO 3166 input format of the country:
-        "auto" (infers the input format), country name ("name"),
-        official state name ("official"), alpha-2 code ("alpha-2"),
-        alpha-3 code ("alpha-3"), numeric code ("numeric")
-    strict
-        If True, matching for input formats "name" and "official" are done by
-        looking for a direct match, if False, matching is done by searching
-        the input for a regex match
-    """
+        The ISO 3166 input format of the country.
+            - 'auto': infer the input format
+            - 'name': country name ('United States')
+            - 'official': official state name ('United States of America')
+            - 'alpha-2': alpha-2 code ('US')
+            - 'alpha-3': alpha-3 code ('USA')
+            - 'numeric': numeric code (840)
 
+        Can also be a tuple containing any combination of input formats,
+        for example to clean a column containing alpha-2 and numeric
+        codes set input_format to ('alpha-2', 'numeric').
+
+        (default: 'auto')
+    strict
+        If True, matching for input formats 'name' and 'official' are done by
+        looking for a direct match, if False, matching is done by searching
+        the input for a regex match.
+
+        (default: False)
+
+    Examples
+    --------
+
+    >>> validate_country('United States')
+    True
+    >>> df = pd.DataFrame({'country': ['Canada', 'NaN']})
+    >>> validate_country(df['country'])
+    0     True
+    1    False
+    Name: country, dtype: bool
+    """
+    input_formats = _input_format_to_tuple(input_format)
     if isinstance(x, pd.Series):
         x = x.astype(str).str.lower().str.strip()
-        return x.apply(_check_country, args=(input_format, strict, False))
+        return x.apply(_check_country, args=(input_formats, strict, False))
 
     x = str(x).lower().strip()
-    return _check_country(x, input_format, strict, False)
+    return _check_country(x, input_formats, strict, False)
 
 
 def _format_country(
     val: Any,
-    input_format: str,
+    input_formats: Tuple[str, ...],
     output_format: str,
     fuzzy_dist: int,
     strict: bool,
@@ -184,9 +245,13 @@ def _format_country(
     # could not be parsed) or "success" (a successful parse of the value).
 
     country = str(val).lower().strip()
-    result_index, status = _check_country(country, input_format, strict, True)
+    result_index, status = _check_country(country, input_formats, strict, True)
 
-    if fuzzy_dist > 0 and status == "unknown" and input_format in ("auto", "name", "official"):
+    if (
+        fuzzy_dist > 0
+        and status == "unknown"
+        and ("name" in input_formats or "official" in input_formats)
+    ):
         result_index, status = _check_fuzzy_dist(country, fuzzy_dist)
 
     if status == "null":
@@ -207,7 +272,7 @@ def _format_country(
 
 
 @lru_cache(maxsize=2 ** 20)
-def _check_country(country: str, input_format: str, strict: bool, clean: bool) -> Any:
+def _check_country(country: str, input_formats: Tuple[str, ...], strict: bool, clean: bool) -> Any:
     """
     Finds the index of the given country in the DATA dataframe.
 
@@ -215,8 +280,8 @@ def _check_country(country: str, input_format: str, strict: bool, clean: bool) -
     ----------
     country
         string containing the country value being cleaned
-    input_format
-        the ISO 3166 input format of the country
+    input_formats
+        Tuple containing potential ISO 3166 input formats of the country
     strict
         If True, for input types "name" and "offical" the function looks for a direct match
         in the DATA dataframe. If False, the country input is searched for a regex match.
@@ -227,12 +292,16 @@ def _check_country(country: str, input_format: str, strict: bool, clean: bool) -
     if country in NULL_VALUES:
         return (None, "null") if clean else False
 
-    if input_format == "auto":
-        input_format = _get_format_from_name(country)
+    country_format = _get_format_from_name(country)
+    input_format = _get_format_if_allowed(country_format, input_formats)
+    if not input_format:
+        return (None, "unknown") if clean else False
 
     if strict and input_format == "regex":
         for form in ("name", "official"):
-            ind = DATA[DATA[form].str.contains(f"^{country}$", flags=re.IGNORECASE, na=False)].index
+            ind = DATA[
+                DATA[form].str.contains(f"^{re.escape(country)}$", flags=re.IGNORECASE, na=False)
+            ].index
             if np.size(ind) > 0:
                 return (ind[0], "success") if clean else True
 
@@ -241,13 +310,11 @@ def _check_country(country: str, input_format: str, strict: bool, clean: bool) -
             if country_regex.search(country):
                 return (index, "success") if clean else True
 
-        # alternative regex search strategy
-        # match = REGEXES.search(country)
-        # if match:
-        #     return (int(match.lastgroup[1:]), "success") if clean else True
     else:
         ind = DATA[
-            DATA[input_format].str.contains(f"^{country}$", flags=re.IGNORECASE, na=False)
+            DATA[input_format].str.contains(
+                f"^{re.escape(country)}$", flags=re.IGNORECASE, na=False
+            )
         ].index
         if np.size(ind) > 0:
             return (ind[0], "success") if clean else True
@@ -288,3 +355,45 @@ def _get_format_from_name(name: str) -> str:
         return "numeric"
     except ValueError:
         return "alpha-2" if len(name) == 2 else "alpha-3" if len(name) == 3 else "regex"
+
+
+def _get_format_if_allowed(input_format: str, allowed_formats: Tuple[str, ...]) -> Optional[str]:
+    """
+    Returns the input format if it's an allowed format.
+    "regex" input_format is only returned if "name" and "official are
+    allowed. This is because when strict = True and input_format = "regex"
+    both the "name" and "official" columns in the DATA dataframe are checked.
+    """
+    if input_format == "regex":
+        if "name" in allowed_formats and "official" in allowed_formats:
+            return "regex"
+
+        return (
+            "name"
+            if "name" in allowed_formats
+            else "official"
+            if "official" in allowed_formats
+            else None
+        )
+
+    return input_format if input_format in allowed_formats else None
+
+
+def _input_format_to_tuple(input_format: Union[str, Tuple[str, ...]]) -> Tuple[str, ...]:
+    """
+    Converts a string input format to a tuple of allowed input formats and raises an error
+    if an input format is not valid.
+    """
+    input_formats = {"auto", "name", "official", "alpha-2", "alpha-3", "numeric"}
+    if isinstance(input_format, str):
+        if input_format == "auto":
+            return ("name", "official", "alpha-2", "alpha-3", "numeric")
+        input_format = (input_format,)
+
+    for fmt in input_format:
+        if fmt not in input_formats:
+            raise ValueError(
+                f'input_format {fmt} is invalid, it needs to be one of "auto", '
+                '"name", "official", "alpha-2", "alpha-3" or "numeric'
+            )
+    return input_format
