@@ -4,12 +4,15 @@ dataprep.eda
 """
 from bokeh.io import output_notebook
 
+from ..utils import is_notebook
 from .correlation import compute_correlation, plot_correlation, render_correlation
 from .create_report import create_report
 from .distribution import compute, plot, render
 from .dtypes import (
     Categorical,
     Continuous,
+    GeoGraphy,
+    GeoPoint,
     DateTime,
     Discrete,
     DType,
@@ -19,7 +22,7 @@ from .dtypes import (
     Text,
 )
 from .missing import compute_missing, plot_missing, render_missing
-from ..utils import is_notebook
+from .diff import plot_diff, compute_diff, render_diff
 
 __all__ = [
     "plot_correlation",
@@ -41,6 +44,9 @@ __all__ = [
     "DateTime",
     "Text",
     "create_report",
+    "plot_diff",
+    "compute_diff",
+    "render_diff",
 ]
 
 
