@@ -5,27 +5,33 @@ from operator import itruediv
 from typing import Optional, Tuple
 
 import dask
-import dask.dataframe as dd
 import dask.array as da
+import dask.dataframe as dd
 import numpy as np
 
+from ...eda_frame import EDAFrame
+from ...configs import Config
 from ...intermediate import Intermediate
 
 
 def _calc_bivariate(
-    df: dd.DataFrame,
+    df: EDAFrame,
+    cfg: Config,
     x: str,
     y: str,
     *,
     k: Optional[int] = None,
 ) -> Intermediate:
-    if x not in df.columns:
+
+    num_df: dd.DataFrame = df.select_num_columns().frame
+
+    if x not in num_df.columns:
         raise ValueError(f"{x} not in columns names")
-    if y not in df.columns:
+    if y not in num_df.columns:
         raise ValueError(f"{y} not in columns names")
 
-    df = df[[x, y]].dropna()
-    coeffs, df_smp, influences = scatter_with_regression(df, sample_size=1000, k=k)
+    num_df = num_df[[x, y]].dropna()
+    coeffs, df_smp, influences = scatter_with_regression(num_df, cfg, k=k)
 
     coeffs, df_smp, influences = dask.compute(coeffs, df_smp, influences)
 
@@ -47,26 +53,23 @@ def _calc_bivariate(
 
 
 def scatter_with_regression(
-    df: dd.DataFrame, sample_size: int, k: Optional[int] = None
+    df: dd.DataFrame, cfg: Config, k: Optional[int] = None
 ) -> Tuple[Tuple[da.Array, da.Array], Tuple[da.Array, da.Array], Optional[da.Array]]:
-    """Calculate pearson correlation on 2 given arrays.
-
-    Parameters
-    ----------
-    df
-        dataframe
-    sample_size
-        Number of points to show in the scatter plot
-    k : Optional[int] = None
-        Highlight k points which influence pearson correlation most
-    """
+    """Sample and compute regression line"""
     df["ones"] = 1
     arr = df.to_dask_array(lengths=True)
 
     (coeffa, coeffb), _, _, _ = da.linalg.lstsq(arr[:, [0, 2]], arr[:, 1])
 
     df = df.drop(columns=["ones"])
-    df_smp = df.map_partitions(lambda x: x.sample(min(sample_size, x.shape[0])), meta=df)
+    if cfg.scatter.sample_size is not None:
+        sample_func = lambda x: x.sample(n=min(cfg.scatter.sample_size, x.shape[0]))
+    else:
+        sample_func = lambda x: x.sample(frac=cfg.scatter.sample_rate)
+    df_smp = df.map_partitions(
+        sample_func,
+        meta=df,
+    )
     # TODO influences should not be computed on a sample
     influences = (
         pearson_influence(
